@@ -134,11 +134,7 @@ class ProcessProtocol(protocol.ProcessProtocol):
             childpids = _mainprocess.children(True)
             buff = dict([(k.pid, k.create_time()) for k in childpids])
             print buff
-            self.transport.signalProcess("KILL")
-            try:
-                _mainprocess.send_signal(9)
-            except:
-                pass
+            self.transport.signalProcess(9)
             for j in childpids:
                 try:
                     _process = psutil.Process(j.pid)
